

*==================================================================
*	Regression Tables/Charts for Publish
*	----------------------------------------------
*	
*	Things needs to be set in preamble
*	----------------------------------------------
*	working directory in "global IN"
*	suffix in "global suffix": tex or csv output
*	----------------------------------------------
*
*		© JaeBin Ahn, Rui Mano, Jing Zhou
*															May 2020
*==================================================================

* -0- Preamble
cls
clear all
set more off
set matsize 11000

global IN "C:\Users\rmano\Box Sync\JMCB_Revision (REER)\JMCB\SubmissionFiles\17-471 R2_codes\codes\empirics"
global suffix "tex"

global Out "\${IN}\tableForPaperNew$FQ$EB.$suffix"


*-0- Summary statistics
//	Table 1: Summary Statistics
use "${IN}\newforECMquarterly.dta", clear
cd "${IN}"
sutex ln_REER_cpi ln_REER_ulc ln_REER_gdp ln_NEER cagdp tbgdp exgdp imgdp, ///
		lab nobs key(Table1) replace file("..\empirics\summary_stat.tex") title("Summary Statistics") minmax
use "${IN}\newforECMAnnual.dta", clear
sutex ln_REER_cpi ln_REER_ulc ln_REER_gdp ln_NEER cagdp tbgdp exgdp imgdp, ///
		lab nobs key(Table1) append file("..\empirics\summary_stat.tex") title("Summary Statistics") minmax			

**********************************
*				Here begins the regressions
**********************************
use "${IN}\newforECMquarterly.dta", clear

*-1- Benchmark with dfe
//	Table 2: Baseline specification with quarterly data
global EB "ca"													// current account
global EBtitle "$EB to GDP ratio"
foreach option in dfe {
	estimates drop _all
	foreach Y in $EB {
		foreach X in cpi ulc gdp {
			xtpmg d.`Y'gdp d.(logDD2 logFD2 ln_REER_`X')  , lr(l.`Y'gdp l1.(logDD2 logFD2 ln_REER_`X')) ec(ec) replace `option' cluster(id)
				count if e(sample)
				estadd scalar obs =`r(N)'
				estimates store `X'`option'
		}
	}
}
	esttab ulcdfe cpidfe gdpdfe using "${Out}", noobs ///
		cells(b(star fmt(3)) se(par fmt(2))) ///
		scalars("obs") ///
		star(* 0.10 ** 0.05 *** 0.001) ///
		title($EBtitle vs. REER ECM `option') ///
		rename(L.ln_REER_cpi "LR_REER" D.ln_REER_cpi "SR_REER" SR:ec "SR_ec" ///
			L.ln_REER_ulc "LR_REER" D.ln_REER_ulc "SR_REER" ///
			L.ln_REER_ppi "LR_REER" D.ln_REER_ppi "SR_REER" ///
			L.ln_REER_gdp "LR_REER" D.ln_REER_gdp "SR_REER" ///
			L.logFD2 "LR_FD" D.logFD2 "SR_FD" L.logDD2 "LR_DD" D.logDD2 "SR_DD") ///
		mtitles(ulc cpi gdp) ///
		drop(_cons) ///
		replace

		
		
*-2- Robustness check with mg/dfe/pmg		
// 	Table 3: Short-run and Long-run Restrictions on the Baseline Specification with Quarterly Data
foreach option in /*dfe*/ mg pmg {
	foreach Y in $EB {
		foreach X in cpi ulc gdp {
			xtpmg d.`Y'gdp d.(logDD2 logFD2 ln_REER_`X'), lr(l.`Y'gdp l1.(logDD2 logFD2 ln_REER_`X')) ec(ec) replace `option' cluster(id) 
				count if e(sample)
				estadd scalar obs =`r(N)'
				estimates store `X'`option'
			if ("`option'" !="dfe") {
				hausman `X'`option' `X'dfe, sigmamore
				estadd scalar hausman_vsDFEpvalue =`r(p)'
				estimates store `X'`option'
			}
		}
	}
}
	esttab ulcpmg cpipmg gdppmg ulcmg cpimg gdpmg using "$Out", noobs ///
		cells(b(star fmt(3)) se(par fmt(2))) ///
		scalars("obs" "hausman_vsDFEpvalue") ///
		star(* 0.10 ** 0.05 *** 0.001) ///
		rename(L.ln_REER_ulc "LR_REER" D.ln_REER_ulc "SR_REER" SR:ec "SR_ec" ///
			L.ln_REER_cpi "LR_REER" D.ln_REER_cpi "SR_REER" ///
			L.ln_REER_ppi "LR_REER" D.ln_REER_ppi "SR_REER" ///
			L.ln_REER_gdp "LR_REER" D.ln_REER_gdp "SR_REER" ///
			L.logFD2 "LR_FD" D.logFD2 "SR_FD" L.logDD2 "LR_DD" D.logDD2 "SR_DD") ///
		mtitles(ulc cpi gdp ulc cpi gdp) ///
		title(Differe Longrun/Shortrun Restrictions) ///
		drop(_cons) ///
		append
		
		
		
		
		
*-3- different lags	
//	Table 4: Lagged Baseline Specification with Quarterly Data
foreach option in dfe {
	foreach Y in $EB {
		foreach X in ulc cpi gdp {
			xtpmg d.`Y'gdp d.(logDD2 logFD2 ln_REER_`X'), lr(l.`Y'gdp l1.(logDD2 logFD2 ln_REER_`X')) ec(ec) replace dfe cluster(id)
				count if e(sample)
				estadd scalar obs =`r(N)'
				estimates store `X'`option'0
			forvalues i =1/4 {
				loc j =`i'*4
				xtpmg d.`Y'gdp d.(logDD2 logFD2 ln_REER_`X') L(1/4)D.(logDD2 logFD2) L(1/`j')D.(ln_REER_`X'), lr(l.`Y'gdp l1.(logDD2 logFD2 ln_REER_`X')) ec(ec) replace `option' cluster(id)
					count if e(sample)
					estadd scalar obs =`r(N)'
					estimates store `X'`option'`i'
			}
		esttab `X'`option'0 `X'`option'1 `X'`option'2 `X'`option'3 `X'`option'4 using "$Out", noobs ///
			cells(b(star fmt(3)) se(par fmt(2))) ///
			scalars("obs") ///
			star(* 0.10 ** 0.05 *** 0.001) ///
			rename(SR:ec "SR_ec" ///
				L.ln_REER_`X' "LR_`X'" D.ln_REER_`X' "SR_`X'" ///
				D1.ln_REER_`X' "SR_`X'" ///
				L4D.ln_REER_`X' "lag_1" ///
				L8D.ln_REER_`X' "lag_2" ///
				L12D.ln_REER_`X' "lag_3" ///
				L16D.ln_REER_`X' "lag_4" ///
				L.logFD2 "LR_FD" D.logFD2 "SR_FD" L.logDD2 "LR_DD" D.logDD2 "SR_DD") ///
			mtitles(ADL(1.1) (2.2) (3.3) (4.4) (5.5)) ///
			keep(*LR*`X' *SR*`X' lag*) ///
			title(With Different Lags [`X'-`option']) ///
			append
		}
	}
}	



*-4- trade balance
//	Table 5:Trade Balance-to-GDP Ratio: Baseline Specification with Quarterly Data
global EB "tb"													// trade balance
global EBtitle "$EB to GDP ratio"
foreach option in dfe {
	estimates drop _all
	foreach Y in $EB {
		foreach X in cpi ulc gdp {
			xtpmg d.`Y'gdp d.(logDD2 logFD2 ln_REER_`X')  , lr(l.`Y'gdp l1.(logDD2 logFD2 ln_REER_`X')) ec(ec) replace `option' cluster(id)
				count if e(sample)
				estadd scalar obs =`r(N)'
				estimates store `X'`option'
		}
	}
}
	esttab ulcdfe cpidfe gdpdfe using "${Out}", noobs ///
		cells(b(star fmt(3)) se(par fmt(2))) ///
		scalars("obs") ///
		star(* 0.10 ** 0.05 *** 0.001) ///
		title($EBtitle vs. REER ECM `option') ///
		rename(L.ln_REER_cpi "LR_REER" D.ln_REER_cpi "SR_REER" SR:ec "SR_ec" ///
			L.ln_REER_ulc "LR_REER" D.ln_REER_ulc "SR_REER" ///
			L.ln_REER_ppi "LR_REER" D.ln_REER_ppi "SR_REER" ///
			L.ln_REER_gdp "LR_REER" D.ln_REER_gdp "SR_REER" ///
			L.logFD2 "LR_FD" D.logFD2 "SR_FD" L.logDD2 "LR_DD" D.logDD2 "SR_DD") ///
		mtitles(ulc cpi gdp) ///
		drop(_cons) ///
		append		

		
		
		
		
		
		
**********************************
*				Here begins the chart
**********************************
use "${IN}\newforECMannual.dta", clear
gen NEER =exp(ln_NEER)
gen REER_cpi =exp(ln_REER_cpi)
gen REER_ulc =exp(ln_REER_ulc)
gen REER_gdp=exp(ln_REER_gdp)

	label var NEER "NEER"
	label var REER_cpi "REERcpi"
	label var REER_ulc "REERulc"
	label var REER_gdp "REERgdp"
	local freq ="Annual"
	keep if country == "China" | ///
			country == "Korea" | ///
			country == "Greece" | ///
			country == "Spain" | ///
			country == "United States" | ///
			country == "Italy"
			
xtset id Annual		
			
	levelsof country, local(levels)
	loc s =0
	loc freq Annual
	foreach name of local levels {
			loc ++s
			if ("`name'" =="China") {
			scatter NEER `freq' if country =="`name'", m(i) mc(blue) msize(medlarge) c(l) lp(l) lc(blue) lw(thick) sort(`freq') ysc(r(80 280)) ylabel(80(40)280) title("`name'", box bexpand) legend(r(2) c(4) ring(1)  pos(11) bmargin(zero)) || ///
			scatter REER_cpi `freq' if country  =="`name'", m(i) mc(gs4) msize(medlarge) c(l) lp(dot) lc(gs4) lw(thick) sort(`freq') ysc(r(80 280)) ylabel(80(40)280) || ///
			scatter REER_ulc `freq' if country  =="`name'", m(i) mc(gs4) msize(medlarge) c(l) lp(l) lc(gs4) lw(thick) sort(`freq') ysc(r(80 280)) ylabel(80(40)280) || ///
			scatter REER_gdp `freq' if country  =="`name'", m(i) mc(gs4) msize(medlarge) c(l) lp(dash) lc(gs4) lw(thick) sort(`freq') ysc(r(80 280)) ylabel(80(40)280)  ///
			|| scatter cagdp `freq' if country  =="`name'", m(i) mc(red) msize(medlarge) c(l) lc(red) lw(thick) sort(`freq') yaxis(2) xsc(r(1995 2017)) xlabel(1995(5)2017)  xtitle("") name(g`s', replace)
			}
			else {
			scatter NEER `freq' if country  =="`name'", m(i) mc(blue) msize(medlarge) c(l) lp(l) lc(blue) lw(thick) sort(`freq') ysc(r(80 160)) ylabel(80(20)160) title("`name'", box bexpand) legend(r(2) c(4) ring(1)  pos(11) bmargin(zero)) || ///
			scatter REER_cpi `freq' if country  =="`name'", m(i) mc(gs4) msize(medlarge) c(l) lp(dot) lc(gs4) lw(thick) sort(`freq') ysc(r(80 160)) ylabel(80(20)160) || ///
			scatter REER_ulc `freq' if country  =="`name'", m(i) mc(gs4) msize(medlarge) c(l) lp(l) lc(gs4) lw(thick) sort(`freq') ysc(r(80 160)) ylabel(80(20)160) || ///
			scatter REER_gdp `freq' if country  =="`name'", m(i) mc(gs4) msize(medlarge) c(l) lp(dash) lc(gs4) lw(thick) sort(`freq') ysc(r(80 160)) ylabel(80(20)160)  ///
			|| scatter cagdp `freq' if country  =="`name'", m(i) mc(red) msize(medlarge) c(l) lc(red) lw(thick) sort(`freq') yaxis(2) xsc(r(1995 2017)) xlabel(1995(5)2017)  xtitle("")  name(g`s', replace)
			}
	}
		graph combine g2 g3 g5 g1 g4 g6, /// 
			imargin(0 2 0 0) graphregion(margin(l=5 r=5)) ///
			row(2) col(3) graphregion(color(white)) xsize(20) ysize(14) altshrink
		gr export "..\empirics\samplecountry.pdf", replace
