% calvo type of rigidity in both wage and final goods price
addpath('C:\Users\jzhou\My Local Documents\4.5.0\matlab\');
//monetary policy(peg) option
@#define peg        =0
@#define taylor     =1


%--------------------------------------------------------------------------
%       variable define
%--------------------------------------------------------------------------
var wtilde  w   kw  fw  dsw     yint    l   c   ptilde     kp  fp  dsp 
    wtilde_ w_  kw_ fw_ dsw_    yint_   l_  c_  ptilde_   kp_ fp_ dsp_ 
    i   i_   pi  pi_ s_slead              
    kwaux   fwaux   kpaux   fpaux   mc  muc
    kwaux_  fwaux_  kpaux_  fpaux_  mc_  a ishock 
    rercpi rerulc rergdp	
    tb tby y y_ tb_ ca nfa b cay epy imy ep im epv imv;         


varexo eps_m eps_a;

parameters BETA SIGMA NU ALPHA GAMMA PHIw PHIp LAMBDAw LAMBDAp RHOi RHOpi RHOy RHOa ySS;

%--------------------------------------------------------------------------
%       parameterization
%--------------------------------------------------------------------------
BETA    =0.99;
SIGMA   =2;
NU      =1;
ALPHA   =0.75;
GAMMA   =2;
PHIw    =6;  
PHIp    =6;  
LAMBDAw =0.75;  
LAMBDAp =0.85;  
RHOi    =0.78;
RHOpi   =1.5;
RHOy    =0.5;
RHOa    =0.9;
ySS     =ln( (PHIp-1)*(PHIw-1)/PHIp/PHIw )/(NU+SIGMA);




%--------------------------------------------------------------------------
%       model
%--------------------------------------------------------------------------
model;

%   1. wage rigidity
    ( exp(wtilde)/exp(w) )^(1+PHIw*NU)  =   exp(kw)/exp(fw);
    exp(kwaux)  =   (exp(w)*exp(pi))^(PHIw*(1+NU))*exp(kw);
    exp(kw) =   PHIw/(PHIw-1)*exp(l)^(1+NU) +   BETA*LAMBDAw*exp(w)^(-PHIw*(1+NU))*exp(kwaux(+1));
    exp(fwaux)  =   (exp(w)*exp(pi))^(PHIw-1)*exp(fw);
    exp(fw) =   exp(c)^(-SIGMA)*exp(w)*exp(l)    +   BETA*LAMBDAw/exp(w)^(PHIw-1)*exp(fwaux(+1));
    LAMBDAw*exp(w(-1))^(1-PHIw) +   (1-LAMBDAw)*(exp(wtilde)*exp(pi))^(1-PHIw)    =   (exp(w)*exp(pi))^(1-PHIw);

%   7. intermediate goods supply
    exp(dsw)	=   (1-LAMBDAw)*(exp(wtilde)/exp(w))^(-PHIw) + LAMBDAw*(exp(w(-1))/exp(w)/exp(pi))^(-PHIw)*exp(dsw(-1));
    exp(yint)   =   exp(a)*exp(l)*exp(dsw);

%   9. final goods price rigidity
    exp(ptilde) =   exp(kp)/exp(fp);
    exp(kpaux)  =   exp(pi)^PHIp*exp(kp);
    exp(kp) =   PHIp/(PHIp-1)*exp(c)^(1-SIGMA)*exp(mc)   +   BETA*LAMBDAp*exp(kpaux(+1));
    exp(fpaux)  =   exp(pi)^(PHIp-1)*exp(fp);
    exp(fp) =   exp(c)^(1-SIGMA)    +   BETA*LAMBDAp*exp(fpaux(+1));
    LAMBDAp*exp(pi)^(-1+PHIp) +   (1-LAMBDAp)*(exp(ptilde))^(1-PHIp)    =   1;

%   15. intermediate goods demand
    exp(yint)   =   ALPHA*(exp(w)/exp(a)/exp(mc))^(-GAMMA)*exp(c)*exp(dsp)  +   (1-ALPHA)*(exp(w)*exp(rercpi)/exp(a)/exp(mc_))^(-GAMMA)*exp(c_)*exp(dsp_);
    exp(dsp)    =   (1-LAMBDAp)*exp(ptilde)^(-PHIp)    +   LAMBDAp*exp(pi)^(PHIp)*exp(dsp(-1));
    exp(mc)     =   ( ALPHA*(exp(w)/exp(a))^(1-GAMMA) +   (1-ALPHA)*(exp(w_)/exp(rercpi))^(1-GAMMA) )^(1/(1-GAMMA));

%   18. Euler equation
    exp(muc)    =   exp(c)^(-SIGMA)/exp(pi);
    exp(c)^(-SIGMA)    =   BETA*exp(i)*exp(muc(+1));

%   20. complete market
    exp(c)^SIGMA    =   exp(c_)^SIGMA/exp(rercpi);

%   21. monetary policy or peg
    i_  =   RHOi*i_(-1)+(1-RHOi)*(ln(1/BETA)+RHOpi*pi_+RHOy*(y_-ySS));
    @#if taylor == 1
            i   =   RHOi*i(-1)+(1-RHOi)*(ln(1/BETA)+RHOpi*pi+RHOy*(y-ySS))+eps_m;
        @#else
        @#if peg ==1
            s_slead =0;
        @#endif
    @#endif


%   24. foreign counterparts
    ( exp(wtilde_)/exp(w_) )^(1+PHIw*NU)  =   exp(kw_)/exp(fw_);
    exp(kwaux_)  =   (exp(w_)*exp(pi_))^(PHIw*(1+NU))*exp(kw_);
    exp(kw_) =   PHIw/(PHIw-1)*exp(l_)^(1+NU) +   BETA*LAMBDAw*exp(w_)^(-PHIw*(1+NU))*exp(kwaux_(+1));
    exp(fwaux_)  =   (exp(w_)*exp(pi_))^(PHIw-1)*exp(fw_);
    exp(fw_) =   exp(c_)^(-SIGMA)*exp(w_)*exp(l_)    +   BETA*LAMBDAw/exp(w_)^(PHIw-1)*exp(fwaux_(+1));
    LAMBDAw*exp(w_(-1))^(1-PHIw) +   (1-LAMBDAw)*(exp(wtilde_)*exp(pi_))^(1-PHIw)    =   (exp(w_)*exp(pi_))^(1-PHIw);
    exp(dsw_)	=   (1-LAMBDAw)*(exp(wtilde_)/exp(w_))^(-PHIw) + LAMBDAw*(exp(w_(-1))/exp(w_)/exp(pi_))^(-PHIw)*exp(dsw_(-1));
    exp(yint_)   =   exp(l_)*exp(dsw_);
    exp(ptilde_) =   exp(kp_)/exp(fp_);
    exp(kpaux_)  =   exp(pi_)^PHIp*exp(kp_);
    exp(kp_) =   PHIp/(PHIp-1)*exp(c_)^(1-SIGMA)*exp(mc_)   +   BETA*LAMBDAp*exp(kpaux_(+1));
    exp(fpaux_)  =   exp(pi_)^(PHIp-1)*exp(fp_);
    exp(fp_) =   exp(c_)^(1-SIGMA)    +   BETA*LAMBDAp*exp(fpaux_(+1));
    LAMBDAp*exp(pi_)^(-1+PHIp) +   (1-LAMBDAp)*(exp(ptilde_))^(1-PHIp)    =   1;
    exp(yint_)   =   ALPHA*(exp(w_)/exp(mc_))^(-GAMMA)*exp(c_)*exp(dsp_)  +   (1-ALPHA)*(exp(w_)/exp(rercpi)/exp(mc))^(-GAMMA)*exp(c)*exp(dsp);
    exp(dsp_)    =   (1-LAMBDAp)*exp(ptilde_)^(-PHIp)    +   LAMBDAp*exp(pi_)^(PHIp)*exp(dsp_(-1));
    exp(mc_)     =   ( ALPHA*exp(w_)^(1-GAMMA) +   (1-ALPHA)*(exp(w)/exp(a)*exp(rercpi))^(1-GAMMA) )^(1/(1-GAMMA));
    exp(s_slead) =  exp(rercpi(-1))/exp(rercpi)*exp(pi)/exp(pi_);
    exp(i)  =   exp(i_)*exp(s_slead(+1));

%   43. rers and external balance
    tb  = exp(w)/exp(a)*(1-ALPHA)*(exp(w)*exp(rercpi)/exp(a)/exp(mc_))^(-GAMMA)*exp(c_)*exp(dsp_)  -  exp(w_)/exp(rercpi)*(1-ALPHA)*(exp(w_)/exp(rercpi)/exp(mc))^(-GAMMA)*exp(c)*exp(dsp);
    exp(y) = exp(c) + tb;
    tby = tb/exp(y);
    exp(ep) =exp(w)/exp(a)*(1-ALPHA)*(exp(w)*exp(rercpi)/exp(a)/exp(mc_))^(-GAMMA)*exp(c_)*exp(dsp_);
    exp(epv)=(1-ALPHA)*(exp(w)*exp(rercpi)/exp(a)/exp(mc_))^(-GAMMA)*exp(c_)*exp(dsp_);
    epy = exp(ep)/exp(y);
    exp(im) =exp(w_)/exp(rercpi)*(1-ALPHA)*(exp(w_)/exp(rercpi)/exp(mc))^(-GAMMA)*exp(c)*exp(dsp);
    exp(imv) =(1-ALPHA)*(exp(w_)/exp(rercpi)/exp(mc))^(-GAMMA)*exp(c)*exp(dsp);
    imy = exp(im)/exp(y);
    tb_ = exp(w_)*(1-ALPHA)*(exp(w_)/exp(rercpi)/exp(mc))^(-GAMMA)*exp(c)*exp(dsp) - exp(w)/exp(a)*exp(rercpi)*(1-ALPHA)*(exp(w)*exp(rercpi)/exp(a)/exp(mc_))^(-GAMMA)*exp(c_)*exp(dsp_);
    exp(y_) = exp(c_) +  tb_;
    exp(rergdp) = 	exp(rercpi)*exp(y)/exp(y_)/(PHIp/(PHIp-1)*PHIw/(PHIw-1)*exp(c)+ PHIw/(PHIw-1)*tb) * (PHIp/(PHIp-1)*PHIw/(PHIw-1)*exp(c_)-PHIw/(PHIw-1)*tb);
    exp(rerulc) =   exp(rercpi)*exp(w)/exp(w_)/exp(a);


    a =RHOa*a(-1) + eps_a;
    ishock =RHOi*ishock(-1)+eps_m;
    nfa =BETA*exp(c(+1))^(-SIGMA)/exp(c)^(-SIGMA)/exp(pi(+1))*b;
    ca  =(nfa(+1)-nfa)/10;
    nfa(+1) =tb+b;
    cay =ca/exp(y);
end;




%--------------------------------------------------------------------------
%       steady state
%--------------------------------------------------------------------------
steady_state_model;
    l       =ln( (PHIp-1)*(PHIw-1)/PHIp/PHIw )/(NU+SIGMA);
    wtilde  =ln((PHIp-1)/PHIp);
    w       =wtilde;
    kw      =ln( 1/(1-BETA*LAMBDAw)*PHIw/(PHIw-1)*exp(l)^(1+NU) );
    fw      =kw;
    dsw     =ln(1);
    yint    =l;
    c       =l;
    ptilde  =ln(1);
    kp      =ln( 1/(1-BETA*LAMBDAp)*exp(c)^(1-SIGMA) );
    fp      =kp;
    dsp     =ln(1);
    pi      =ln(1);
    kwaux   =ln( (exp(w)*exp(pi))^(PHIw*(1+NU))*exp(kw) );
    fwaux   =ln( (exp(w)*exp(pi))^(PHIw-1)*exp(fw) );
    kpaux   =ln( exp(pi)^PHIp*exp(kp) );
    fpaux   =ln( exp(pi)^(PHIp-1)*exp(fp) );
    mc      =w;
    muc     =ln( exp(c)^(-SIGMA)/exp(pi) );
    i       =ln(1/BETA);
    

    wtilde_	=   wtilde;
    w_      =	w;
    kw_     =	kw;
    fw_     =	fw;
    dsw_	=	dsw;
    yint_	=	yint;
    l_      =	l;
    c_      =	c;
    ptilde_	=	ptilde;
    kp_     =	kp;
    fp_     =	fp;
    dsp_	=	dsp;
    kwaux_	=	kwaux;
    fwaux_	=	fwaux;
    kpaux_	=	kpaux;
    fpaux_	=	fpaux;
    mc_     =	mc;
    i_      =	i;
    pi_     =	pi;
   
    rercpi =0;
    rerulc =0;
    rergdp =0;
    tb     =0;
    tb_    =0;
    tby    =0;
    y      =c;
    y_     =y;
    s_slead =ln(1);
    
    ca     =0;
    cay    =0;
    b      =0;
    nfa    =0;
    ep     =ln( exp(w)*(1-ALPHA)*(exp(w)*exp(rercpi)/exp(mc_))^(-GAMMA)*exp(c_)*exp(dsp_) );
    epy    =exp(ep)/exp(y);
    imy    =epy;
    im     =ep;
    imv    =ln((1-ALPHA)*(exp(w_)/exp(rercpi)/exp(mc))^(-GAMMA)*exp(c)*exp(dsp));
    epv    =imv;
    
    a      =0;
    ishock =0;
end;
  


%--------------------------------------------------------------------------
%       shocks
%--------------------------------------------------------------------------
shocks;
    var eps_m      =0.005^2;
    var eps_a      =0.0001;
end;


steady;
check;

set(0,'DefaultFigureWindowStyle','docked')
stoch_simul(order=1,irf=21,periods=4000,drop=500,nograph);
